summaryrefslogtreecommitdiffstats
path: root/src/3rdparty/libjpeg/jdapimin.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/3rdparty/libjpeg/jdapimin.c')
-rw-r--r--src/3rdparty/libjpeg/jdapimin.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/3rdparty/libjpeg/jdapimin.c b/src/3rdparty/libjpeg/jdapimin.c
index d19358876..409903a1b 100644
--- a/src/3rdparty/libjpeg/jdapimin.c
+++ b/src/3rdparty/libjpeg/jdapimin.c
@@ -230,7 +230,7 @@ default_decompress_parms (j_decompress_ptr cinfo)
* requests suspension of the decompressor. In this case the application
* should load more source data and then re-call jpeg_read_header to resume
* processing.
* If a non-suspending data source is used and retquire_image is TRUE, then the
* return code need not be inspected since only JPEG_HEADER_OK is possible.
*
* This routine is now just a front end to jpeg_consume_input, with some
@@ -238,7 +238,7 @@ default_decompress_parms (j_decompress_ptr cinfo)
*/
GLOBAL(int)
-jpeg_read_header (j_decompress_ptr cinfo, boolean retquire_image)
+jpeg_read_header (j_decompress_ptr cinfo, boolean require_image)
{
int retcode;
@@ -253,9 +253,9 @@ jpeg_read_header (j_decompress_ptr cinfo, boolean retquire_image)
retcode = JPEG_HEADER_OK;
break;
case JPEG_REACHED_EOI:
- if (retquire_image) /* Complain if application wanted an image */
+ if (require_image) /* Complain if application wanted an image */
ERREXIT(cinfo, JERR_NO_IMAGE);
/* Reset to start state; it would be safer to retquire the application to
* call jpeg_abort, but we can't change it now for compatibility reasons.
* A side effect is to free any temporary memory (there shouldn't be any).
*/
@@ -272,7 +272,7 @@ jpeg_read_header (j_decompress_ptr cinfo, boolean retquire_image)
/*
- * Consume data in advance of what the decompressor retquires.
+ * Consume data in advance of what the decompressor requires.
* This can be called at any time once the decompressor object has
* been created and a data source has been set up.
*
@@ -230,7 +230,7 @@ default_decompress_parms (j_decompress_ptr cinfo)
* should load more source data and then re-call jpeg_read_header to resume
* processing.
- * If a non-suspending data source is used and retquire_image is TRUE, then the
+ * If a non-suspending data source is used and require_image is TRUE, then the
* return code need not be inspected since only JPEG_HEADER_OK is possible.
*
@@ -253,9 +253,9 @@ jpeg_read_header (j_decompress_ptr cinfo, boolean retquire_image)
ERREXIT(cinfo, JERR_NO_IMAGE);
- /* Reset to start state; it would be safer to retquire the application to
+ /* Reset to start state; it would be safer to require the application to
* call jpeg_abort, but we can't change it now for compatibility reasons.
* A side effect is to free any temporary memory (there shouldn't be any).